@@ -200,16 +200,16 @@ namespace Model
     /**
      * <p>A version of the build input to be built, for this build only. If not
      * specified, the latest version is used. If specified, must be one of:</p> <ul>
-     * <li> <p>For AWS CodeCommit: the commit ID to use.</p> </li> <li> <p>For GitHub:
-     * the commit ID, pull request ID, branch name, or tag name that corresponds to the
-     * version of the source code you want to build. If a pull request ID is specified,
-     * it must use the format <code>pr/pull-request-ID</code> (for example
-     * <code>pr/25</code>). If a branch name is specified, the branch's HEAD commit ID
-     * is used. If not specified, the default branch's HEAD commit ID is used.</p>
-     * </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name that
-     * corresponds to the version of the source code you want to build. If a branch
-     * name is specified, the branch's HEAD commit ID is used. If not specified, the
-     * default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
+     * <li> <p>For AWS CodeCommit: the commit ID, branch, or Git tag to use.</p> </li>
+     * <li> <p>For GitHub: the commit ID, pull request ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a pull
+     * request ID is specified, it must use the format <code>pr/pull-request-ID</code>
+     * (for example <code>pr/25</code>). If a branch name is specified, the branch's
+     * HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is
+     * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a
+     * branch name is specified, the branch's HEAD commit ID is used. If not specified,
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
      * Storage Service (Amazon S3): the version ID of the object that represents the
      * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
      * is specified at the project level, then this <code>sourceVersion</code> (at the
@@ -222,16 +222,16 @@ namespace Model
     /**
      * <p>A version of the build input to be built, for this build only. If not
      * specified, the latest version is used. If specified, must be one of:</p> <ul>
-     * <li> <p>For AWS CodeCommit: the commit ID to use.</p> </li> <li> <p>For GitHub:
-     * the commit ID, pull request ID, branch name, or tag name that corresponds to the
-     * version of the source code you want to build. If a pull request ID is specified,
-     * it must use the format <code>pr/pull-request-ID</code> (for example
-     * <code>pr/25</code>). If a branch name is specified, the branch's HEAD commit ID
-     * is used. If not specified, the default branch's HEAD commit ID is used.</p>
-     * </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name that
-     * corresponds to the version of the source code you want to build. If a branch
-     * name is specified, the branch's HEAD commit ID is used. If not specified, the
-     * default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
+     * <li> <p>For AWS CodeCommit: the commit ID, branch, or Git tag to use.</p> </li>
+     * <li> <p>For GitHub: the commit ID, pull request ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a pull
+     * request ID is specified, it must use the format <code>pr/pull-request-ID</code>
+     * (for example <code>pr/25</code>). If a branch name is specified, the branch's
+     * HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is
+     * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a
+     * branch name is specified, the branch's HEAD commit ID is used. If not specified,
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
      * Storage Service (Amazon S3): the version ID of the object that represents the
      * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
      * is specified at the project level, then this <code>sourceVersion</code> (at the
@@ -244,16 +244,16 @@ namespace Model
     /**
      * <p>A version of the build input to be built, for this build only. If not
      * specified, the latest version is used. If specified, must be one of:</p> <ul>
-     * <li> <p>For AWS CodeCommit: the commit ID to use.</p> </li> <li> <p>For GitHub:
-     * the commit ID, pull request ID, branch name, or tag name that corresponds to the
-     * version of the source code you want to build. If a pull request ID is specified,
-     * it must use the format <code>pr/pull-request-ID</code> (for example
-     * <code>pr/25</code>). If a branch name is specified, the branch's HEAD commit ID
-     * is used. If not specified, the default branch's HEAD commit ID is used.</p>
-     * </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name that
-     * corresponds to the version of the source code you want to build. If a branch
-     * name is specified, the branch's HEAD commit ID is used. If not specified, the
-     * default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
+     * <li> <p>For AWS CodeCommit: the commit ID, branch, or Git tag to use.</p> </li>
+     * <li> <p>For GitHub: the commit ID, pull request ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a pull
+     * request ID is specified, it must use the format <code>pr/pull-request-ID</code>
+     * (for example <code>pr/25</code>). If a branch name is specified, the branch's
+     * HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is
+     * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a
+     * branch name is specified, the branch's HEAD commit ID is used. If not specified,
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
      * Storage Service (Amazon S3): the version ID of the object that represents the
      * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
      * is specified at the project level, then this <code>sourceVersion</code> (at the
@@ -266,16 +266,16 @@ namespace Model
     /**
      * <p>A version of the build input to be built, for this build only. If not
      * specified, the latest version is used. If specified, must be one of:</p> <ul>
-     * <li> <p>For AWS CodeCommit: the commit ID to use.</p> </li> <li> <p>For GitHub:
-     * the commit ID, pull request ID, branch name, or tag name that corresponds to the
-     * version of the source code you want to build. If a pull request ID is specified,
-     * it must use the format <code>pr/pull-request-ID</code> (for example
-     * <code>pr/25</code>). If a branch name is specified, the branch's HEAD commit ID
-     * is used. If not specified, the default branch's HEAD commit ID is used.</p>
-     * </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name that
-     * corresponds to the version of the source code you want to build. If a branch
-     * name is specified, the branch's HEAD commit ID is used. If not specified, the
-     * default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
+     * <li> <p>For AWS CodeCommit: the commit ID, branch, or Git tag to use.</p> </li>
+     * <li> <p>For GitHub: the commit ID, pull request ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a pull
+     * request ID is specified, it must use the format <code>pr/pull-request-ID</code>
+     * (for example <code>pr/25</code>). If a branch name is specified, the branch's
+     * HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is
+     * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a
+     * branch name is specified, the branch's HEAD commit ID is used. If not specified,
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
      * Storage Service (Amazon S3): the version ID of the object that represents the
      * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
      * is specified at the project level, then this <code>sourceVersion</code> (at the
@@ -288,16 +288,16 @@ namespace Model
     /**
      * <p>A version of the build input to be built, for this build only. If not
      * specified, the latest version is used. If specified, must be one of:</p> <ul>
-     * <li> <p>For AWS CodeCommit: the commit ID to use.</p> </li> <li> <p>For GitHub:
-     * the commit ID, pull request ID, branch name, or tag name that corresponds to the
-     * version of the source code you want to build. If a pull request ID is specified,
-     * it must use the format <code>pr/pull-request-ID</code> (for example
-     * <code>pr/25</code>). If a branch name is specified, the branch's HEAD commit ID
-     * is used. If not specified, the default branch's HEAD commit ID is used.</p>
-     * </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name that
-     * corresponds to the version of the source code you want to build. If a branch
-     * name is specified, the branch's HEAD commit ID is used. If not specified, the
-     * default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
+     * <li> <p>For AWS CodeCommit: the commit ID, branch, or Git tag to use.</p> </li>
+     * <li> <p>For GitHub: the commit ID, pull request ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a pull
+     * request ID is specified, it must use the format <code>pr/pull-request-ID</code>
+     * (for example <code>pr/25</code>). If a branch name is specified, the branch's
+     * HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is
+     * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a
+     * branch name is specified, the branch's HEAD commit ID is used. If not specified,
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
      * Storage Service (Amazon S3): the version ID of the object that represents the
      * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
      * is specified at the project level, then this <code>sourceVersion</code> (at the
@@ -310,16 +310,16 @@ namespace Model
     /**
      * <p>A version of the build input to be built, for this build only. If not
      * specified, the latest version is used. If specified, must be one of:</p> <ul>
-     * <li> <p>For AWS CodeCommit: the commit ID to use.</p> </li> <li> <p>For GitHub:
-     * the commit ID, pull request ID, branch name, or tag name that corresponds to the
-     * version of the source code you want to build. If a pull request ID is specified,
-     * it must use the format <code>pr/pull-request-ID</code> (for example
-     * <code>pr/25</code>). If a branch name is specified, the branch's HEAD commit ID
-     * is used. If not specified, the default branch's HEAD commit ID is used.</p>
-     * </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name that
-     * corresponds to the version of the source code you want to build. If a branch
-     * name is specified, the branch's HEAD commit ID is used. If not specified, the
-     * default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
+     * <li> <p>For AWS CodeCommit: the commit ID, branch, or Git tag to use.</p> </li>
+     * <li> <p>For GitHub: the commit ID, pull request ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a pull
+     * request ID is specified, it must use the format <code>pr/pull-request-ID</code>
+     * (for example <code>pr/25</code>). If a branch name is specified, the branch's
+     * HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is
+     * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a
+     * branch name is specified, the branch's HEAD commit ID is used. If not specified,
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
      * Storage Service (Amazon S3): the version ID of the object that represents the
      * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
      * is specified at the project level, then this <code>sourceVersion</code> (at the
@@ -332,16 +332,16 @@ namespace Model
     /**
      * <p>A version of the build input to be built, for this build only. If not
      * specified, the latest version is used. If specified, must be one of:</p> <ul>
-     * <li> <p>For AWS CodeCommit: the commit ID to use.</p> </li> <li> <p>For GitHub:
-     * the commit ID, pull request ID, branch name, or tag name that corresponds to the
-     * version of the source code you want to build. If a pull request ID is specified,
-     * it must use the format <code>pr/pull-request-ID</code> (for example
-     * <code>pr/25</code>). If a branch name is specified, the branch's HEAD commit ID
-     * is used. If not specified, the default branch's HEAD commit ID is used.</p>
-     * </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name that
-     * corresponds to the version of the source code you want to build. If a branch
-     * name is specified, the branch's HEAD commit ID is used. If not specified, the
-     * default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
+     * <li> <p>For AWS CodeCommit: the commit ID, branch, or Git tag to use.</p> </li>
+     * <li> <p>For GitHub: the commit ID, pull request ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a pull
+     * request ID is specified, it must use the format <code>pr/pull-request-ID</code>
+     * (for example <code>pr/25</code>). If a branch name is specified, the branch's
+     * HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is
+     * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a
+     * branch name is specified, the branch's HEAD commit ID is used. If not specified,
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
      * Storage Service (Amazon S3): the version ID of the object that represents the
      * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
      * is specified at the project level, then this <code>sourceVersion</code> (at the
@@ -354,16 +354,16 @@ namespace Model
     /**
      * <p>A version of the build input to be built, for this build only. If not
      * specified, the latest version is used. If specified, must be one of:</p> <ul>
-     * <li> <p>For AWS CodeCommit: the commit ID to use.</p> </li> <li> <p>For GitHub:
-     * the commit ID, pull request ID, branch name, or tag name that corresponds to the
-     * version of the source code you want to build. If a pull request ID is specified,
-     * it must use the format <code>pr/pull-request-ID</code> (for example
-     * <code>pr/25</code>). If a branch name is specified, the branch's HEAD commit ID
-     * is used. If not specified, the default branch's HEAD commit ID is used.</p>
-     * </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name that
-     * corresponds to the version of the source code you want to build. If a branch
-     * name is specified, the branch's HEAD commit ID is used. If not specified, the
-     * default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
+     * <li> <p>For AWS CodeCommit: the commit ID, branch, or Git tag to use.</p> </li>
+     * <li> <p>For GitHub: the commit ID, pull request ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a pull
+     * request ID is specified, it must use the format <code>pr/pull-request-ID</code>
+     * (for example <code>pr/25</code>). If a branch name is specified, the branch's
+     * HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is
+     * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
+     * that corresponds to the version of the source code you want to build. If a
+     * branch name is specified, the branch's HEAD commit ID is used. If not specified,
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
      * Storage Service (Amazon S3): the version ID of the object that represents the
      * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
      * is specified at the project level, then this <code>sourceVersion</code> (at the
@@ -697,50 +697,122 @@ namespace Model
 
 
     /**
-     * <p>A build spec declaration that overrides, for this build only, the latest one
-     * already defined in the build project.</p>
+     * <p>A buildspec file declaration that overrides, for this build only, the latest
+     * one already defined in the build project.</p> <p> If this value is set, it can
+     * be either an inline buildspec definition, the path to an alternate buildspec
+     * file relative to the value of the built-in <code>CODEBUILD_SRC_DIR</code>
+     * environment variable, or the path to an S3 bucket. The bucket must be in the
+     * same AWS Region as the build project. Specify the buildspec file using its ARN
+     * (for example, <code>arn:aws:s3:::my-codebuild-sample2/buildspec.yml</code>). If
+     * this value is not provided or is set to an empty string, the source code must
+     * contain a buildspec file in its root directory. For more information, see <a
+     * href="https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage">Buildspec
+     * File Name and Storage Location</a>. </p>
      */
     inline const Aws::String& GetBuildspecOverride() const{ return m_buildspecOverride; }
 
     /**
-     * <p>A build spec declaration that overrides, for this build only, the latest one
-     * already defined in the build project.</p>
+     * <p>A buildspec file declaration that overrides, for this build only, the latest
+     * one already defined in the build project.</p> <p> If this value is set, it can
+     * be either an inline buildspec definition, the path to an alternate buildspec
+     * file relative to the value of the built-in <code>CODEBUILD_SRC_DIR</code>
+     * environment variable, or the path to an S3 bucket. The bucket must be in the
+     * same AWS Region as the build project. Specify the buildspec file using its ARN
+     * (for example, <code>arn:aws:s3:::my-codebuild-sample2/buildspec.yml</code>). If
+     * this value is not provided or is set to an empty string, the source code must
+     * contain a buildspec file in its root directory. For more information, see <a
+     * href="https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage">Buildspec
+     * File Name and Storage Location</a>. </p>
      */
     inline bool BuildspecOverrideHasBeenSet() const { return m_buildspecOverrideHasBeenSet; }
 
     /**
-     * <p>A build spec declaration that overrides, for this build only, the latest one
-     * already defined in the build project.</p>
+     * <p>A buildspec file declaration that overrides, for this build only, the latest
+     * one already defined in the build project.</p> <p> If this value is set, it can
+     * be either an inline buildspec definition, the path to an alternate buildspec
+     * file relative to the value of the built-in <code>CODEBUILD_SRC_DIR</code>
+     * environment variable, or the path to an S3 bucket. The bucket must be in the
+     * same AWS Region as the build project. Specify the buildspec file using its ARN
+     * (for example, <code>arn:aws:s3:::my-codebuild-sample2/buildspec.yml</code>). If
+     * this value is not provided or is set to an empty string, the source code must
+     * contain a buildspec file in its root directory. For more information, see <a
+     * href="https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage">Buildspec
+     * File Name and Storage Location</a>. </p>
      */
     inline void SetBuildspecOverride(const Aws::String& value) { m_buildspecOverrideHasBeenSet = true; m_buildspecOverride = value; }
 
     /**
-     * <p>A build spec declaration that overrides, for this build only, the latest one
-     * already defined in the build project.</p>
+     * <p>A buildspec file declaration that overrides, for this build only, the latest
+     * one already defined in the build project.</p> <p> If this value is set, it can
+     * be either an inline buildspec definition, the path to an alternate buildspec
+     * file relative to the value of the built-in <code>CODEBUILD_SRC_DIR</code>
+     * environment variable, or the path to an S3 bucket. The bucket must be in the
+     * same AWS Region as the build project. Specify the buildspec file using its ARN
+     * (for example, <code>arn:aws:s3:::my-codebuild-sample2/buildspec.yml</code>). If
+     * this value is not provided or is set to an empty string, the source code must
+     * contain a buildspec file in its root directory. For more information, see <a
+     * href="https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage">Buildspec
+     * File Name and Storage Location</a>. </p>
      */
     inline void SetBuildspecOverride(Aws::String&& value) { m_buildspecOverrideHasBeenSet = true; m_buildspecOverride = std::move(value); }
 
     /**
-     * <p>A build spec declaration that overrides, for this build only, the latest one
-     * already defined in the build project.</p>
+     * <p>A buildspec file declaration that overrides, for this build only, the latest
+     * one already defined in the build project.</p> <p> If this value is set, it can
+     * be either an inline buildspec definition, the path to an alternate buildspec
+     * file relative to the value of the built-in <code>CODEBUILD_SRC_DIR</code>
+     * environment variable, or the path to an S3 bucket. The bucket must be in the
+     * same AWS Region as the build project. Specify the buildspec file using its ARN
+     * (for example, <code>arn:aws:s3:::my-codebuild-sample2/buildspec.yml</code>). If
+     * this value is not provided or is set to an empty string, the source code must
+     * contain a buildspec file in its root directory. For more information, see <a
+     * href="https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage">Buildspec
+     * File Name and Storage Location</a>. </p>
      */
     inline void SetBuildspecOverride(const char* value) { m_buildspecOverrideHasBeenSet = true; m_buildspecOverride.assign(value); }
 
     /**
-     * <p>A build spec declaration that overrides, for this build only, the latest one
-     * already defined in the build project.</p>
+     * <p>A buildspec file declaration that overrides, for this build only, the latest
+     * one already defined in the build project.</p> <p> If this value is set, it can
+     * be either an inline buildspec definition, the path to an alternate buildspec
+     * file relative to the value of the built-in <code>CODEBUILD_SRC_DIR</code>
+     * environment variable, or the path to an S3 bucket. The bucket must be in the
+     * same AWS Region as the build project. Specify the buildspec file using its ARN
+     * (for example, <code>arn:aws:s3:::my-codebuild-sample2/buildspec.yml</code>). If
+     * this value is not provided or is set to an empty string, the source code must
+     * contain a buildspec file in its root directory. For more information, see <a
+     * href="https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage">Buildspec
+     * File Name and Storage Location</a>. </p>
      */
     inline StartBuildRequest& WithBuildspecOverride(const Aws::String& value) { SetBuildspecOverride(value); return *this;}
 
     /**
-     * <p>A build spec declaration that overrides, for this build only, the latest one
-     * already defined in the build project.</p>
+     * <p>A buildspec file declaration that overrides, for this build only, the latest
+     * one already defined in the build project.</p> <p> If this value is set, it can
+     * be either an inline buildspec definition, the path to an alternate buildspec
+     * file relative to the value of the built-in <code>CODEBUILD_SRC_DIR</code>
+     * environment variable, or the path to an S3 bucket. The bucket must be in the
+     * same AWS Region as the build project. Specify the buildspec file using its ARN
+     * (for example, <code>arn:aws:s3:::my-codebuild-sample2/buildspec.yml</code>). If
+     * this value is not provided or is set to an empty string, the source code must
+     * contain a buildspec file in its root directory. For more information, see <a
+     * href="https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage">Buildspec
+     * File Name and Storage Location</a>. </p>
      */
     inline StartBuildRequest& WithBuildspecOverride(Aws::String&& value) { SetBuildspecOverride(std::move(value)); return *this;}
 
     /**
-     * <p>A build spec declaration that overrides, for this build only, the latest one
-     * already defined in the build project.</p>
+     * <p>A buildspec file declaration that overrides, for this build only, the latest
+     * one already defined in the build project.</p> <p> If this value is set, it can
+     * be either an inline buildspec definition, the path to an alternate buildspec
+     * file relative to the value of the built-in <code>CODEBUILD_SRC_DIR</code>
+     * environment variable, or the path to an S3 bucket. The bucket must be in the
+     * same AWS Region as the build project. Specify the buildspec file using its ARN
+     * (for example, <code>arn:aws:s3:::my-codebuild-sample2/buildspec.yml</code>). If
+     * this value is not provided or is set to an empty string, the source code must
+     * contain a buildspec file in its root directory. For more information, see <a
+     * href="https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage">Buildspec
+     * File Name and Storage Location</a>. </p>
      */
     inline StartBuildRequest& WithBuildspecOverride(const char* value) { SetBuildspecOverride(value); return *this;}
 
@@ -1148,6 +1220,95 @@ namespace Model
     inline StartBuildRequest& WithQueuedTimeoutInMinutesOverride(int value) { SetQueuedTimeoutInMinutesOverride(value); return *this;}
 
 
+    /**
+     * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) that
+     * overrides the one specified in the build project. The CMK key encrypts the build
+     * output artifacts.</p> <note> <p> You can use a cross-account KMS key to encrypt
+     * the build output artifacts if your service role has permission to that key. </p>
+     * </note> <p>You can specify either the Amazon Resource Name (ARN) of the CMK or,
+     * if available, the CMK's alias (using the format <code>alias/<i>alias-name</i>
+     * </code>).</p>
+     */
+    inline const Aws::String& GetEncryptionKeyOverride() const{ return m_encryptionKeyOverride; }
+
+    /**
+     * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) that
+     * overrides the one specified in the build project. The CMK key encrypts the build
+     * output artifacts.</p> <note> <p> You can use a cross-account KMS key to encrypt
+     * the build output artifacts if your service role has permission to that key. </p>
+     * </note> <p>You can specify either the Amazon Resource Name (ARN) of the CMK or,
+     * if available, the CMK's alias (using the format <code>alias/<i>alias-name</i>
+     * </code>).</p>
+     */
+    inline bool EncryptionKeyOverrideHasBeenSet() const { return m_encryptionKeyOverrideHasBeenSet; }
+
+    /**
+     * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) that
+     * overrides the one specified in the build project. The CMK key encrypts the build
+     * output artifacts.</p> <note> <p> You can use a cross-account KMS key to encrypt
+     * the build output artifacts if your service role has permission to that key. </p>
+     * </note> <p>You can specify either the Amazon Resource Name (ARN) of the CMK or,
+     * if available, the CMK's alias (using the format <code>alias/<i>alias-name</i>
+     * </code>).</p>
+     */
+    inline void SetEncryptionKeyOverride(const Aws::String& value) { m_encryptionKeyOverrideHasBeenSet = true; m_encryptionKeyOverride = value; }
+
+    /**
+     * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) that
+     * overrides the one specified in the build project. The CMK key encrypts the build
+     * output artifacts.</p> <note> <p> You can use a cross-account KMS key to encrypt
+     * the build output artifacts if your service role has permission to that key. </p>
+     * </note> <p>You can specify either the Amazon Resource Name (ARN) of the CMK or,
+     * if available, the CMK's alias (using the format <code>alias/<i>alias-name</i>
+     * </code>).</p>
+     */
+    inline void SetEncryptionKeyOverride(Aws::String&& value) { m_encryptionKeyOverrideHasBeenSet = true; m_encryptionKeyOverride = std::move(value); }
+
+    /**
+     * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) that
+     * overrides the one specified in the build project. The CMK key encrypts the build
+     * output artifacts.</p> <note> <p> You can use a cross-account KMS key to encrypt
+     * the build output artifacts if your service role has permission to that key. </p>
+     * </note> <p>You can specify either the Amazon Resource Name (ARN) of the CMK or,
+     * if available, the CMK's alias (using the format <code>alias/<i>alias-name</i>
+     * </code>).</p>
+     */
+    inline void SetEncryptionKeyOverride(const char* value) { m_encryptionKeyOverrideHasBeenSet = true; m_encryptionKeyOverride.assign(value); }
+
+    /**
+     * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) that
+     * overrides the one specified in the build project. The CMK key encrypts the build
+     * output artifacts.</p> <note> <p> You can use a cross-account KMS key to encrypt
+     * the build output artifacts if your service role has permission to that key. </p>
+     * </note> <p>You can specify either the Amazon Resource Name (ARN) of the CMK or,
+     * if available, the CMK's alias (using the format <code>alias/<i>alias-name</i>
+     * </code>).</p>
+     */
+    inline StartBuildRequest& WithEncryptionKeyOverride(const Aws::String& value) { SetEncryptionKeyOverride(value); return *this;}
+
+    /**
+     * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) that
+     * overrides the one specified in the build project. The CMK key encrypts the build
+     * output artifacts.</p> <note> <p> You can use a cross-account KMS key to encrypt
+     * the build output artifacts if your service role has permission to that key. </p>
+     * </note> <p>You can specify either the Amazon Resource Name (ARN) of the CMK or,
+     * if available, the CMK's alias (using the format <code>alias/<i>alias-name</i>
+     * </code>).</p>
+     */
+    inline StartBuildRequest& WithEncryptionKeyOverride(Aws::String&& value) { SetEncryptionKeyOverride(std::move(value)); return *this;}
+
+    /**
+     * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) that
+     * overrides the one specified in the build project. The CMK key encrypts the build
+     * output artifacts.</p> <note> <p> You can use a cross-account KMS key to encrypt
+     * the build output artifacts if your service role has permission to that key. </p>
+     * </note> <p>You can specify either the Amazon Resource Name (ARN) of the CMK or,
+     * if available, the CMK's alias (using the format <code>alias/<i>alias-name</i>
+     * </code>).</p>
+     */
+    inline StartBuildRequest& WithEncryptionKeyOverride(const char* value) { SetEncryptionKeyOverride(value); return *this;}
+
+
     /**
      * <p>A unique, case sensitive identifier you provide to ensure the idempotency of
      * the StartBuild request. The token is included in the StartBuild request and is
@@ -1427,6 +1588,9 @@ namespace Model
     int m_queuedTimeoutInMinutesOverride;
     bool m_queuedTimeoutInMinutesOverrideHasBeenSet;
 
+    Aws::String m_encryptionKeyOverride;
+    bool m_encryptionKeyOverrideHasBeenSet;
+
     Aws::String m_idempotencyToken;
     bool m_idempotencyTokenHasBeenSet;
 
