@@ -28,6 +28,7 @@
 #include <aws/ec2/model/GpuInfo.h>
 #include <aws/ec2/model/FpgaInfo.h>
 #include <aws/ec2/model/PlacementGroupInfo.h>
+#include <aws/ec2/model/InferenceAcceleratorInfo.h>
 #include <aws/ec2/model/UsageClassType.h>
 #include <aws/ec2/model/RootDeviceType.h>
 #include <utility>
@@ -189,44 +190,44 @@ namespace Model
 
 
     /**
-     * <p>Indicates the supported root devices.</p>
+     * <p>Indicates the supported root device types.</p>
      */
-    inline const Aws::Vector<RootDeviceType>& GetSupportedRootDevices() const{ return m_supportedRootDevices; }
+    inline const Aws::Vector<RootDeviceType>& GetSupportedRootDeviceTypes() const{ return m_supportedRootDeviceTypes; }
 
     /**
-     * <p>Indicates the supported root devices.</p>
+     * <p>Indicates the supported root device types.</p>
      */
-    inline bool SupportedRootDevicesHasBeenSet() const { return m_supportedRootDevicesHasBeenSet; }
+    inline bool SupportedRootDeviceTypesHasBeenSet() const { return m_supportedRootDeviceTypesHasBeenSet; }
 
     /**
-     * <p>Indicates the supported root devices.</p>
+     * <p>Indicates the supported root device types.</p>
      */
-    inline void SetSupportedRootDevices(const Aws::Vector<RootDeviceType>& value) { m_supportedRootDevicesHasBeenSet = true; m_supportedRootDevices = value; }
+    inline void SetSupportedRootDeviceTypes(const Aws::Vector<RootDeviceType>& value) { m_supportedRootDeviceTypesHasBeenSet = true; m_supportedRootDeviceTypes = value; }
 
     /**
-     * <p>Indicates the supported root devices.</p>
+     * <p>Indicates the supported root device types.</p>
      */
-    inline void SetSupportedRootDevices(Aws::Vector<RootDeviceType>&& value) { m_supportedRootDevicesHasBeenSet = true; m_supportedRootDevices = std::move(value); }
+    inline void SetSupportedRootDeviceTypes(Aws::Vector<RootDeviceType>&& value) { m_supportedRootDeviceTypesHasBeenSet = true; m_supportedRootDeviceTypes = std::move(value); }
 
     /**
-     * <p>Indicates the supported root devices.</p>
+     * <p>Indicates the supported root device types.</p>
      */
-    inline InstanceTypeInfo& WithSupportedRootDevices(const Aws::Vector<RootDeviceType>& value) { SetSupportedRootDevices(value); return *this;}
+    inline InstanceTypeInfo& WithSupportedRootDeviceTypes(const Aws::Vector<RootDeviceType>& value) { SetSupportedRootDeviceTypes(value); return *this;}
 
     /**
-     * <p>Indicates the supported root devices.</p>
+     * <p>Indicates the supported root device types.</p>
      */
-    inline InstanceTypeInfo& WithSupportedRootDevices(Aws::Vector<RootDeviceType>&& value) { SetSupportedRootDevices(std::move(value)); return *this;}
+    inline InstanceTypeInfo& WithSupportedRootDeviceTypes(Aws::Vector<RootDeviceType>&& value) { SetSupportedRootDeviceTypes(std::move(value)); return *this;}
 
     /**
-     * <p>Indicates the supported root devices.</p>
+     * <p>Indicates the supported root device types.</p>
      */
-    inline InstanceTypeInfo& AddSupportedRootDevices(const RootDeviceType& value) { m_supportedRootDevicesHasBeenSet = true; m_supportedRootDevices.push_back(value); return *this; }
+    inline InstanceTypeInfo& AddSupportedRootDeviceTypes(const RootDeviceType& value) { m_supportedRootDeviceTypesHasBeenSet = true; m_supportedRootDeviceTypes.push_back(value); return *this; }
 
     /**
-     * <p>Indicates the supported root devices.</p>
+     * <p>Indicates the supported root device types.</p>
      */
-    inline InstanceTypeInfo& AddSupportedRootDevices(RootDeviceType&& value) { m_supportedRootDevicesHasBeenSet = true; m_supportedRootDevices.push_back(std::move(value)); return *this; }
+    inline InstanceTypeInfo& AddSupportedRootDeviceTypes(RootDeviceType&& value) { m_supportedRootDeviceTypesHasBeenSet = true; m_supportedRootDeviceTypes.push_back(std::move(value)); return *this; }
 
 
     /**
@@ -581,6 +582,37 @@ namespace Model
     inline InstanceTypeInfo& WithPlacementGroupInfo(PlacementGroupInfo&& value) { SetPlacementGroupInfo(std::move(value)); return *this;}
 
 
+    /**
+     * <p>Describes the Inference accelerator settings for the instance type.</p>
+     */
+    inline const InferenceAcceleratorInfo& GetInferenceAcceleratorInfo() const{ return m_inferenceAcceleratorInfo; }
+
+    /**
+     * <p>Describes the Inference accelerator settings for the instance type.</p>
+     */
+    inline bool InferenceAcceleratorInfoHasBeenSet() const { return m_inferenceAcceleratorInfoHasBeenSet; }
+
+    /**
+     * <p>Describes the Inference accelerator settings for the instance type.</p>
+     */
+    inline void SetInferenceAcceleratorInfo(const InferenceAcceleratorInfo& value) { m_inferenceAcceleratorInfoHasBeenSet = true; m_inferenceAcceleratorInfo = value; }
+
+    /**
+     * <p>Describes the Inference accelerator settings for the instance type.</p>
+     */
+    inline void SetInferenceAcceleratorInfo(InferenceAcceleratorInfo&& value) { m_inferenceAcceleratorInfoHasBeenSet = true; m_inferenceAcceleratorInfo = std::move(value); }
+
+    /**
+     * <p>Describes the Inference accelerator settings for the instance type.</p>
+     */
+    inline InstanceTypeInfo& WithInferenceAcceleratorInfo(const InferenceAcceleratorInfo& value) { SetInferenceAcceleratorInfo(value); return *this;}
+
+    /**
+     * <p>Describes the Inference accelerator settings for the instance type.</p>
+     */
+    inline InstanceTypeInfo& WithInferenceAcceleratorInfo(InferenceAcceleratorInfo&& value) { SetInferenceAcceleratorInfo(std::move(value)); return *this;}
+
+
     /**
      * <p>Indicates whether On-Demand hibernation is supported.</p>
      */
@@ -682,8 +714,8 @@ namespace Model
     Aws::Vector<UsageClassType> m_supportedUsageClasses;
     bool m_supportedUsageClassesHasBeenSet;
 
-    Aws::Vector<RootDeviceType> m_supportedRootDevices;
-    bool m_supportedRootDevicesHasBeenSet;
+    Aws::Vector<RootDeviceType> m_supportedRootDeviceTypes;
+    bool m_supportedRootDeviceTypesHasBeenSet;
 
     bool m_bareMetal;
     bool m_bareMetalHasBeenSet;
@@ -721,6 +753,9 @@ namespace Model
     PlacementGroupInfo m_placementGroupInfo;
     bool m_placementGroupInfoHasBeenSet;
 
+    InferenceAcceleratorInfo m_inferenceAcceleratorInfo;
+    bool m_inferenceAcceleratorInfoHasBeenSet;
+
     bool m_hibernationSupported;
     bool m_hibernationSupportedHasBeenSet;
 
