@@ -259,6 +259,31 @@ namespace Model
     inline PutPlaybackConfigurationRequest& WithName(const char* value) { SetName(value); return *this;}
 
 
+    /**
+     * <p>The maximum duration of underfilled ad time (in seconds) allowed in an ad
+     * break.</p>
+     */
+    inline int GetPersonalizationThresholdSeconds() const{ return m_personalizationThresholdSeconds; }
+
+    /**
+     * <p>The maximum duration of underfilled ad time (in seconds) allowed in an ad
+     * break.</p>
+     */
+    inline bool PersonalizationThresholdSecondsHasBeenSet() const { return m_personalizationThresholdSecondsHasBeenSet; }
+
+    /**
+     * <p>The maximum duration of underfilled ad time (in seconds) allowed in an ad
+     * break.</p>
+     */
+    inline void SetPersonalizationThresholdSeconds(int value) { m_personalizationThresholdSecondsHasBeenSet = true; m_personalizationThresholdSeconds = value; }
+
+    /**
+     * <p>The maximum duration of underfilled ad time (in seconds) allowed in an ad
+     * break.</p>
+     */
+    inline PutPlaybackConfigurationRequest& WithPersonalizationThresholdSeconds(int value) { SetPersonalizationThresholdSeconds(value); return *this;}
+
+
     /**
      * <p>The URL for a high-quality video asset to transcode and use to fill in time
      * that's not used by ads. AWS Elemental MediaTailor shows the slate to fill in
@@ -536,6 +561,9 @@ namespace Model
     Aws::String m_name;
     bool m_nameHasBeenSet;
 
+    int m_personalizationThresholdSeconds;
+    bool m_personalizationThresholdSecondsHasBeenSet;
+
     Aws::String m_slateAdUrl;
     bool m_slateAdUrlHasBeenSet;
 
